
# Type: disease or phenotypic feature association to location association_object




URI: [biolink:disease_or_phenotypic_feature_association_to_location_association_object](https://w3id.org/biolink/vocab/disease_or_phenotypic_feature_association_to_location_association_object)


## Domain and Range

[DiseaseOrPhenotypicFeatureAssociationToLocationAssociation](DiseaseOrPhenotypicFeatureAssociationToLocationAssociation.md) ->  <sub>REQ</sub> [AnatomicalEntity](AnatomicalEntity.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [DiseaseOrPhenotypicFeatureAssociationToLocationAssociation](DiseaseOrPhenotypicFeatureAssociationToLocationAssociation.md)
